@@ -1212,6 +1212,8 @@ function s010_cave.OnSubAreaChange(old_subarea, old_actorgroup, new_subarea, new
       cu_door.LIFE:LockDoor()
     end
   end
+
+  Scenario.UpdateProgressiveItemModels()
 end
 
 
@@ -2110,6 +2112,7 @@ function s010_cave.OnUsableCancelUse(_ARG_0_)
   end
 
   Scenario.ResetGlobalTeleport(actor)
+  Scenario.CheckWarpToStart(actor)
 end
 
 function s010_cave.OnUsablePrepareUse(_ARG_0_)
